"""empty message

Revision ID: e2bbe7fd9bc7
Revises: b142d6d9e8da
Create Date: 2019-05-20 23:22:16.784309

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e2bbe7fd9bc7'
down_revision = 'b142d6d9e8da'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('meta_cache',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('isbn', sa.String(length=13), nullable=True),
    sa.Column('service', sa.String(length=10), nullable=True),
    sa.Column('date', sa.DateTime(), nullable=True),
    sa.Column('data', sa.Text(), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('meta_cache')
    # ### end Alembic commands ###
