"""empty message

Revision ID: 91732d5540b9
Revises: e2bbe7fd9bc7
Create Date: 2019-06-06 22:52:21.057872

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '91732d5540b9'
down_revision = 'e2bbe7fd9bc7'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('books', sa.Column('metadata_source', sa.String(length=20), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('books', 'metadata_source')
    # ### end Alembic commands ###
